@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.004_05';
+our $VERSION = '0.005_01';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -106,6 +106,9 @@ __PACKAGE__->add_property( 'alien_repository_class'   => {} );
 __PACKAGE__->add_property( 'alien_isolate_dynamic' => 0 );
 __PACKAGE__->add_property( 'alien_autoconf_with_pic' => 1 );
 
+# alien_inline_auto_include
+__PACKAGE__->add_property( 'alien_inline_auto_include' => [] );
+
 ################
 #  ConfigData  #
 ################
@@ -136,6 +139,10 @@ sub new {
   # setup additional temporary directories, and yes we have to add File::ShareDir manually
   $self->_add_prereq( 'requires', 'File::ShareDir', '1.00' );
 
+  # this just gets passed from the Build.PL to the config so that it can
+  # be used by the auto_include method
+  $self->config_data( 'inline_auto_include' => $self->alien_inline_auto_include );
+
   if (grep /(?<!\%)\%c/, @{ $self->alien_build_commands }) {
     $self->config_data( 'autoconf' => 1 );
   }
@@ -682,7 +689,7 @@ sub alien_generate_manual_pkgconfig {
 
   #if no provides_libs then generate -l list from found files
   unless ($provides_libs) {
-    my @files = map { "-l$_" } @{$paths->{so_files}};
+    my @files = map { "-l$_" } @{$paths->{lib_files}};
     $provides_libs = join( ' ', @files );
   } 
 
@@ -712,12 +719,18 @@ sub alien_generate_manual_pkgconfig {
   return $manual_pc;
 }
 
-sub _alien_file_pattern {
+sub _alien_file_pattern_dynamic {
   my $self = shift;
   my $ext = $self->config('so'); #platform specific .so extension
-  return qr/\.[\d.]*(?<=\.)$ext[\d.]*(?<!\.)|\.h$/;
+  return qr/\.[\d.]*(?<=\.)$ext[\d.]*(?<!\.)|(\.h|$ext)$/;
 };
 
+sub _alien_file_pattern_static {
+  my $self = shift;
+  my $ext = quotemeta $self->config('lib_ext');
+  return qr/(\.h|$ext)$/;
+}
+
 sub alien_find_lib_paths {
   my $self = shift;
   my ($dir) = @_;
@@ -726,43 +739,52 @@ sub alien_find_lib_paths {
   my @libs;
   @libs = grep { s/^-l// } split /\s+/, $libs if $libs;
 
-  my $file_pattern = $self->_alien_file_pattern;
+  my (@lib_files, @lib_paths, @inc_paths);
 
-  my @files =     
-    map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
-    grep { ! -d }
-    @{ $self->_rscan_destdir( $dir, $file_pattern ) };
+  foreach my $file_pattern ($self->_alien_file_pattern_static, $self->_alien_file_pattern_dynamic) {
 
-  my (@so_files, @lib_paths, @inc_paths);
-  for (@files) {
+    my @files =     
+      map { File::Spec->abs2rel( $_, $dir ) }  # make relative to $dir
+      grep { ! -d }
+      @{ $self->_rscan_destdir( $dir, $file_pattern ) };
 
-    my ($file, $path, $ext) = fileparse( $_, $file_pattern );
-    next unless $ext; # just in case
+    use YAML ();
+    print YAML::Dump({ files => \@files });
 
-    $path = File::Spec->catdir($path); # remove trailing /
+    for (@files) {
 
-    if ($ext eq '.h') {
-      push @inc_paths, $path;
-      next;
+      my ($file, $path, $ext) = fileparse( $_, $file_pattern );
+      next unless $ext; # just in case
+
+      $path = File::Spec->catdir($path); # remove trailing /
+
+      if ($ext eq '.h') {
+        push @inc_paths, $path;
+        next;
+      }
+
+      $file =~ s/^lib//;
+      
+      if (@libs) {
+        next unless grep { $file eq $_ } @libs;
+      }
+      
+      $DB::single = 1;
+      
+      next if grep { $file eq $_ } @lib_files;
+
+      push @lib_files, $file;
+      push @lib_paths, $path;
     }
-
-    $file =~ s/^lib//;
-
-    if (@libs) {
-      next unless grep { $file eq $_ } @libs;
-    }
-
-    push @so_files, $file;
-    push @lib_paths, $path;
   }
 
-  @so_files = uniq @so_files;
-  @so_files = sort @so_files;
+  @lib_files = uniq @lib_files;
+  @lib_files = sort @lib_files;
 
   @lib_paths = uniq @lib_paths;
   @inc_paths = uniq @inc_paths;
 
-  return { lib => \@lib_paths, inc => \@inc_paths, so_files => \@so_files };
+  return { lib => \@lib_paths, inc => \@inc_paths, lib_files => \@lib_files };
 }
 
 sub alien_refresh_packlist {
@@ -830,8 +852,60 @@ Alien::Base::ModuleBuild - A Module::Build subclass for building Alien:: modules
 
 =head1 SYNOPSIS
 
+In your Build.PL:
+
+ use Alien::Base::ModuleBuild;
+ 
+ my $builder = Alien::Base::Module::Build->new(
+   module_name => 'Alien::MyLibrary',
+   
+   configure_requires => {
+     'Alien::Base' =>   '0.005',
+     'Module::Build' => '0.28'
+   },
+   requires => {
+     'Alien::Base' => '0.005',
+   },
+   
+   alien_name => 'mylibrary', # the pkg-config name if you want
+                              # to use pkg-config to discover
+                              # system version of the mylibrary
+   
+   alien_repository => {
+     protocol => 'http',
+     host     => 'myhost.org',
+     location => '/path/to/tarballs',
+     pattern  => qr{^mylibrary-([0-9\.]+)\.tar\.gz$},
+   },
+   
+   # this is the default:
+   alien_build_commands => [
+     "%c --prefix=%s", # %c is a platform independent version of ./configure
+     "make",
+   ],
+   
+   # this is the default for install:
+   alien_install_commands => [
+     "make install",
+   ],
+   
+   alien_isolate_dynamic => 1,
+ );
+
 =head1 DESCRIPTION
 
+This is a subclass of L<Module::Build>, that with L<Alien::Base> allows
+for easy creation of Alien distributions.  This module is used during the
+build step of your distribution.  When properly configured it will
+
+=over 4
+
+=item use pkg-config to find and use the system version of the library
+
+=item download, build and install the library if the system does not provide it
+
+=back
+
 =head1 GUIDE TO DOCUMENTATION
 
 The documentation for C<Module::Build> is broken up into sections:
